@@ -492,6 +492,10 @@ class DidlObject(with_metaclass(DidlMetaClass, object)):
         # Deal with any resource elements
         resources = []
         for res_elt in element.findall(ns_tag('', 'res')):
+            # Not all Favorits have resources, so in case the "res"
+            # tage has no attributes, just skip it
+            if cls is DidlFavorite and not res_elt.attrib:
+                continue
             resources.append(
                 DidlResource.from_element(res_elt))
 
@@ -803,6 +807,14 @@ class DidlAudioBroadcast(DidlAudioItem):
     )
 
 
+class DidlRecentShow(DidlMusicTrack):
+
+    """Class that represents a recent radio show/podcast."""
+
+    # the DIDL Lite class for this object.
+    item_class = 'object.item.audioItem.musicTrack.recentShow'
+
+
 class DidlAudioBroadcastFavorite(DidlAudioBroadcast):
 
     """Class that represents an audio broadcast Sonos favorite."""
@@ -846,6 +858,7 @@ class DidlFavorite(DidlItem):
         # import happened at load time.
         global _FROM_DIDL_STRING_FUNCTION  # pylint: disable=global-statement
         if not _FROM_DIDL_STRING_FUNCTION:
+            # pylint: disable=import-outside-toplevel
             from . import data_structures_entry
             _FROM_DIDL_STRING_FUNCTION = data_structures_entry.from_didl_string
 
@@ -862,6 +875,12 @@ class DidlFavorite(DidlItem):
         self.resources = value.resources
 
 
+class DidlLineInItem(DidlItem):
+
+    """Class that represents a Sonos Line-In."""
+    item_class = 'object.item.audioItem.linein'
+
+
 ###############################################################################
 # OBJECT.CONTAINER HIERARCHY                                                  #
 ###############################################################################
@@ -1051,6 +1070,12 @@ class DidlPlaylistContainerFavorite(DidlPlaylistContainer):
     item_class = 'object.container.playlistContainer.sonos-favorite'
 
 
+class DidlPlaylistContainerTracklist(DidlPlaylistContainer):
+
+    """Class that represents a Sonos tracklist."""
+    item_class = 'object.container.playlistContainer.tracklist'
+
+
 class DidlGenre(DidlContainer):
 
     """A content directory class representing a general genre."""
@@ -1087,6 +1112,13 @@ class DidlRadioShow(DidlContainer):
     # A radio show doesn't seem to have any special attributes
 
 
+class DidlPodcast(DidlContainer):
+    """Dummy class that represents a podcast container."""
+
+    # the DIDL Lite class for this object.
+    item_class = 'object.container.podcast'
+
+
 ###############################################################################
 # SPECIAL LISTS                                                               #
 ###############################################################################
